**************************
 What's New in Pylint 2.9
**************************

:Release: 2.9
:Date: TBA

Summary -- Release highlights
=============================


New checkers
============

Other Changes
=============

* Pylint's tags are now the standard form ``vX.Y.Z`` and not ``pylint-X.Y.Z`` anymore.
